@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-01-27'; # DATE
 our $DIST = 'Sah-Schemas-EAN'; # DIST
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 1;
 # ABSTRACT: Various Sah schemas related to EAN (International/European Article Number)
@@ -22,7 +22,7 @@ Sah::Schemas::EAN - Various Sah schemas related to EAN (International/European A
 
 =head1 VERSION
 
-This document describes version 0.008 of Sah::Schemas::EAN (from Perl distribution Sah-Schemas-EAN), released on 2023-01-27.
+This document describes version 0.009 of Sah::Schemas::EAN (from Perl distribution Sah-Schemas-EAN), released on 2023-01-27.
 
 =head1 SAH SCHEMAS
 
@@ -41,6 +41,17 @@ Checksum digit must be valid.
 Length must be 13 digits.
 
 
+=item * L<ean13_unvalidated|Sah::Schema::ean13_unvalidated>
+
+EAN-13 number (e.g. 5-901234-123457), check digit not validated.
+
+Nondigits [^0-9] will be removed during coercion.
+
+Length must be 13 digits.
+
+This schema can be useful if you want to check EAN-13's check digit yourself.
+
+
 =item * L<ean13_without_check_digit|Sah::Schema::ean13_without_check_digit>
 
 The first 12 digits of an EAN-13 number (eg. 5-901234-12345).
@@ -49,10 +60,13 @@ Nondigits [^0-9] will be removed during coercion.
 
 Length must be 7 digits.
 
+This schema can be useful if you want co calculate the check digit and want to
+accept the first 12 digits as input.
+
 
 =item * L<ean8|Sah::Schema::ean8>
 
-EAN-8 number.
+EAN-8 number (e.g. 9638-5074).
 
 Nondigits [^0-9] will be removed during coercion.
 
@@ -61,6 +75,17 @@ Checksum digit must be valid.
 Length must be 8 digits.
 
 
+=item * L<ean8_unvalidated|Sah::Schema::ean8_unvalidated>
+
+EAN-8 number (e.g. 9638-5074), check digit not validated.
+
+Nondigits [^0-9] will be removed during coercion.
+
+Length must be 8 digits.
+
+This schema can be useful if you want to check EAN-8's check digit yourself.
+
+
 =item * L<ean8_without_check_digit|Sah::Schema::ean8_without_check_digit>
 
 The first 7 digits of an EAN-8 number (eg. 9638-507).
@@ -69,6 +94,9 @@ Nondigits [^0-9] will be removed during coercion.
 
 Length must be 7 digits.
 
+This schema can be useful if you want co calculate the check digit and want to
+accept the first 7 digits as input.
+
 
 =back
 
